@@ -287,43 +287,12 @@ eel_gtk_window_set_initial_geometry_from_string (GtkWindow *window,
  * @event: The event that invoked this popup menu.
  **/
 void
-eel_pop_up_context_menu (GtkMenu	     *menu,
-                         gint16	      offset_x,
-                         gint16	      offset_y,
+eel_pop_up_context_menu (GtkMenu	*menu,
                          GdkEventButton *event)
 {
-    GdkPoint offset;
-    int button;
-
     g_return_if_fail (GTK_IS_MENU (menu));
 
-    offset.x = offset_x;
-    offset.y = offset_y;
-
-    /* The event button needs to be 0 if we're popping up this menu from
-     * a button release, else a 2nd click outside the menu with any button
-     * other than the one that invoked the menu will be ignored (instead
-     * of dismissing the menu). This is a subtle fragility of the GTK menu code.
-     */
-
-    if (event)
-    {
-        button = event->type == GDK_BUTTON_RELEASE
-                 ? 0
-                 : event->button;
-    }
-    else
-    {
-        button = 0;
-    }
-
-    gtk_menu_popup (menu,					/* menu */
-                    NULL,					/* parent_menu_shell */
-                    NULL,					/* parent_menu_item */
-                    NULL,
-                    &offset,			        /* data */
-                    button,					/* button */
-                    event ? event->time : GDK_CURRENT_TIME); /* activate_time */
+    gtk_menu_popup_at_pointer (menu, (const GdkEvent*) event);
 
     g_object_ref_sink (menu);
     g_object_unref (menu);
@@ -388,7 +357,11 @@ eel_gtk_label_make_bold (GtkLabel *label)
      * theme or user prefs, since the font desc only has the
      * weight flag turned on.
      */
-    gtk_widget_override_font (GTK_WIDGET (label), font_desc);
+    PangoAttrList *attrs = pango_attr_list_new ();
+    PangoAttribute *font_desc_attr = pango_attr_font_desc_new (font_desc);
+    pango_attr_list_insert (attrs, font_desc_attr);
+    gtk_label_set_attributes (label, attrs);
+    pango_attr_list_unref (attrs);
 
     pango_font_description_free (font_desc);
 }
@@ -470,3 +443,58 @@ eel_gtk_message_dialog_set_details_label (GtkMessageDialog *dialog,
 	gtk_widget_show (label);
 	gtk_widget_show (expander);
 }
+
+GtkWidget *
+eel_image_menu_item_new_from_icon (const gchar *icon_name,
+                                   const gchar *label_name)
+{
+    GtkWidget *icon;
+    GSettings *icon_settings;
+    GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+
+    icon_settings = g_settings_new ("org.mate.interface");
+    if ((icon_name) && (g_settings_get_boolean (icon_settings, "menus-have-icons")))
+        /*Load the icon if user has icons in menus turned on*/
+        icon = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+    else
+        /*Load an empty icon to hold the space*/
+        icon = gtk_image_new ();
+
+    GtkWidget *label_menu = gtk_label_new_with_mnemonic (g_strconcat (label_name, "     ", NULL));
+    GtkWidget *menuitem = gtk_menu_item_new ();
+
+    gtk_container_add (GTK_CONTAINER (box), icon);
+
+    gtk_container_add (GTK_CONTAINER (box), label_menu);
+ 
+    gtk_container_add (GTK_CONTAINER (menuitem), box);
+    gtk_widget_show_all (menuitem);
+
+    g_object_unref(icon_settings);
+
+    return menuitem;
+}
+
+GtkWidget *
+eel_image_menu_item_new_from_pixbuf (GdkPixbuf   *icon_pixbuf,
+                                     const gchar *label_name)
+{
+    GtkWidget *icon;
+    GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+
+    if (icon_pixbuf)
+        icon = gtk_image_new_from_pixbuf (icon_pixbuf);
+    else
+        icon = gtk_image_new ();
+
+    GtkWidget *label_menu = gtk_label_new (g_strconcat (label_name, "     ", NULL));
+    GtkWidget *menuitem = gtk_menu_item_new ();
+
+    gtk_container_add (GTK_CONTAINER (box), icon);
+    gtk_container_add (GTK_CONTAINER (box), label_menu);
+
+    gtk_container_add (GTK_CONTAINER (menuitem), box);
+    gtk_widget_show_all (menuitem);
+
+    return menuitem;
+}
