@@ -32,8 +32,6 @@
 #include <gtk/gtk.h>
 #include <eel/eel-gdk-extensions.h>
 
-#define EEL_DEFAULT_POPUP_MENU_DISPLACEMENT 	2
-
 /* GtkWindow */
 void                  eel_gtk_window_set_initial_geometry             (GtkWindow            *window,
         EelGdkGeometryFlags   geometry_flags,
@@ -51,8 +49,6 @@ char *                eel_gtk_window_get_geometry_string              (GtkWindow
 
 /* GtkMenu and GtkMenuItem */
 void                  eel_pop_up_context_menu                         (GtkMenu              *menu,
-        gint16                offset_x,
-        gint16                offset_y,
         GdkEventButton       *event);
 GtkMenuItem *         eel_gtk_menu_append_separator                   (GtkMenu              *menu);
 GtkMenuItem *         eel_gtk_menu_insert_separator                   (GtkMenu              *menu,
@@ -65,11 +61,17 @@ GtkWidget *           eel_gtk_menu_tool_button_get_button             (GtkMenuTo
 void                  eel_gtk_label_make_bold                         (GtkLabel             *label);
 
 /* GtkTreeView */
-void                  eel_gtk_tree_view_set_activate_on_single_click  (GtkTreeView               *tree_view,
-        gboolean                   should_activate);
+void                  eel_gtk_tree_view_set_activate_on_single_click  (GtkTreeView          *tree_view,
+                                                                       gboolean              should_activate);
 
 /* GtkMessageDialog */
-void                  eel_gtk_message_dialog_set_details_label        (GtkMessageDialog          *dialog,
-								       const gchar               *details_text);
+void                  eel_gtk_message_dialog_set_details_label        (GtkMessageDialog     *dialog,
+                                                                       const gchar          *details_text);
+
+GtkWidget *           eel_image_menu_item_new_from_icon               (const gchar          *icon_name,
+                                                                       const gchar          *label_name);
+
+GtkWidget *           eel_image_menu_item_new_from_pixbuf               (GdkPixbuf          *icon_pixbuf,
+                                                                         const gchar        *label_name);
 
 #endif /* EEL_GTK_EXTENSIONS_H */
