@@ -585,11 +585,10 @@ caja_bookmark_new (GFile *location, const char *name, gboolean has_custom_name,
     return new_bookmark;
 }
 
-static GtkWidget *
-create_image_widget_for_bookmark (CajaBookmark *bookmark)
+static cairo_surface_t *
+create_image_cairo_for_bookmark (CajaBookmark *bookmark)
 {
     cairo_surface_t *surface;
-    GtkWidget *widget;
 
     surface = caja_bookmark_get_surface (bookmark, GTK_ICON_SIZE_MENU);
     if (surface == NULL)
@@ -597,10 +596,39 @@ create_image_widget_for_bookmark (CajaBookmark *bookmark)
         return NULL;
     }
 
-    widget = gtk_image_new_from_surface (surface);
+    return surface;
+}
 
-    cairo_surface_destroy (surface);
-    return widget;
+static GtkWidget *
+bookmark_image_menu_item_new_from_surface (cairo_surface_t   *icon_surface,
+                                           const gchar       *label_name)
+{
+    GtkWidget *icon;
+    GtkLabel *label;
+
+    GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+
+    if (icon_surface)
+        icon = gtk_image_new_from_surface (icon_surface);
+    else
+        icon = gtk_image_new ();
+
+    GtkWidget *label_menu = gtk_label_new (g_strconcat (label_name, "     ", NULL));
+
+    label = GTK_LABEL (label_menu);
+    gtk_label_set_use_underline (label, FALSE);
+    gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
+    gtk_label_set_max_width_chars (label, (ELLIPSISED_MENU_ITEM_MIN_CHARS + 2));
+
+    GtkWidget *menuitem = gtk_menu_item_new ();
+ 
+    gtk_container_add (GTK_CONTAINER (box), icon);
+    gtk_container_add (GTK_CONTAINER (box), label_menu);
+ 
+    gtk_container_add (GTK_CONTAINER (menuitem), box);
+    gtk_widget_show_all (menuitem);
+
+    return menuitem;
 }
 
 /**
@@ -614,22 +642,11 @@ GtkWidget *
 caja_bookmark_menu_item_new (CajaBookmark *bookmark)
 {
     GtkWidget *menu_item;
-    GtkWidget *image_widget;
-    GtkLabel *label;
+    cairo_surface_t *image_cairo;
 
-    menu_item = gtk_image_menu_item_new_with_label (bookmark->details->name);
-    label = GTK_LABEL (gtk_bin_get_child (GTK_BIN (menu_item)));
-    gtk_label_set_use_underline (label, FALSE);
-    gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
-    gtk_label_set_max_width_chars (label, ELLIPSISED_MENU_ITEM_MIN_CHARS);
+    image_cairo = create_image_cairo_for_bookmark (bookmark);
 
-    image_widget = create_image_widget_for_bookmark (bookmark);
-    if (image_widget != NULL)
-    {
-        gtk_widget_show (image_widget);
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
-                                       image_widget);
-    }
+    menu_item = bookmark_image_menu_item_new_from_surface (image_cairo, bookmark->details->name);
 
     return menu_item;
 }
