@@ -64,7 +64,8 @@ typedef enum
     CAJA_FILE_SORT_BY_ATIME,
     CAJA_FILE_SORT_BY_EMBLEMS,
     CAJA_FILE_SORT_BY_TRASHED_TIME,
-    CAJA_FILE_SORT_BY_SIZE_ON_DISK
+    CAJA_FILE_SORT_BY_SIZE_ON_DISK,
+    CAJA_FILE_SORT_BY_EXTENSION
 } CajaFileSortType;
 
 typedef enum
