@@ -239,10 +239,10 @@ get_progress_window ()
 
     gtk_window_set_title (GTK_WINDOW (progress_window),
                           _("File Operations"));
-    gtk_window_set_wmclass (GTK_WINDOW (progress_window),
-                            "file_progress", "Caja");
+
     gtk_window_set_position (GTK_WINDOW (progress_window),
                              GTK_WIN_POS_CENTER);
+
     gtk_window_set_icon_name (GTK_WINDOW (progress_window),
                               "system-file-manager");
 
@@ -594,28 +594,45 @@ static void
 update_status_icon_and_window (void)
 {
     char *tooltip;
-    gboolean toshow, window_shown;
+    gboolean toshow;
+    GIcon *icon;
+    GNotification *notification;
+    static gboolean window_shown = FALSE;
+
+    notification = g_notification_new ("caja");
+    icon = g_themed_icon_new ("system-file-manager");
+    g_notification_set_icon (notification, icon);
 
     tooltip = g_strdup_printf (ngettext ("%'d file operation active",
                                          "%'d file operations active",
                                          n_progress_ops),
                                n_progress_ops);
+
     gtk_status_icon_set_tooltip_text (status_icon, tooltip);
     g_free (tooltip);
 
     toshow = (n_progress_ops > 0);
-    window_shown = gtk_status_icon_get_visible (status_icon);
 
-    if (!toshow && window_shown)
+    if (!toshow)
     {
         gtk_status_icon_set_visible (status_icon, FALSE);
-        gtk_widget_hide (get_progress_window ());
+
+        if (window_shown)
+        {
+            gtk_widget_hide (get_progress_window ());
+            g_notification_set_body (notification, _("Process completed"));
+            g_application_send_notification (g_application_get_default (), "caja", notification);
+            window_shown = FALSE;
+        }
     }
     else if (toshow && !window_shown)
     {
         gtk_widget_show_all (get_progress_window ());
         gtk_status_icon_set_visible (status_icon, TRUE);
         gtk_window_present (GTK_WINDOW (get_progress_window ()));
+        g_notification_set_body (notification, _("Working..."));
+        g_application_send_notification (g_application_get_default (), "caja", notification);
+        window_shown = TRUE;
     }
 }
 
@@ -809,8 +826,8 @@ progress_widget_new (CajaProgressInfo *info)
 
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
 
-    imgcancel = gtk_image_new_from_icon_name ("gtk-cancel",
-                                      GTK_ICON_SIZE_BUTTON);
+    imgcancel = gtk_image_new_from_icon_name ("process-stop",
+                                              GTK_ICON_SIZE_BUTTON);
 
     btcancel = gtk_button_new ();
     gtk_container_add (GTK_CONTAINER (btcancel), imgcancel);
