@@ -188,7 +188,17 @@ caja_desktop_window_new (CajaApplication *application,
     gtk_window_set_default_size (GTK_WINDOW (window), -1, -1);
 
     /* Special sawmill setting*/
-    gtk_window_set_wmclass (GTK_WINDOW (window), "desktop_window", "Caja");
+    GdkWindow *gdkwin;
+    gtk_widget_realize (GTK_WIDGET (window));
+    gdkwin = gtk_widget_get_window (GTK_WIDGET (window));
+    if (gdk_window_ensure_native (gdkwin)) {
+        Display *disp = GDK_DISPLAY_XDISPLAY (gdk_window_get_display (gdkwin));
+        XClassHint *xch = XAllocClassHint ();
+        xch->res_name = "desktop_window";
+        xch->res_class = "Caja";
+        XSetClassHint (disp, GDK_WINDOW_XID(gdkwin), xch);
+        XFree(xch);
+    }
 
     g_signal_connect (window, "delete_event", G_CALLBACK (caja_desktop_window_delete_event), NULL);
 
