@@ -30,6 +30,8 @@
 #include "caja-notebook.h"
 #include "caja-window-slot.h"
 
+#include <eel/eel-gtk-extensions.h>
+
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-window-slot-info.h>
 #include <libcaja-private/caja-view-factory.h>
@@ -201,9 +203,6 @@ path_bar_location_changed_callback (GtkWidget *widget,
 
     slot = CAJA_NAVIGATION_WINDOW_SLOT (win_pane->active_slot);
 
-    /* Make sure we are changing the location on the correct pane */
-    caja_window_set_active_pane (CAJA_WINDOW_PANE (pane)->window, CAJA_WINDOW_PANE (pane));
-
     /* check whether we already visited the target location */
     i = bookmark_list_get_uri_index (slot->back_list, location);
     if (i >= 0)
@@ -262,63 +261,21 @@ location_button_create (CajaNavigationWindowPane *pane)
 }
 
 static gboolean
-path_bar_button_pressed_callback (GtkWidget *widget,
-                                  GdkEventButton *event,
-                                  CajaNavigationWindowPane *pane)
-{
-    CajaWindowSlot *slot;
-    CajaView *view;
-    GFile *location;
-    char *uri;
+path_bar_path_event_callback (CajaPathBar *path_bar,
+                   GFile *location,
+                   GdkEventButton *event,
+                   CajaWindowPane *pane)
 
-    caja_window_set_active_pane (CAJA_WINDOW_PANE (pane)->window, CAJA_WINDOW_PANE (pane));
-
-    g_object_set_data (G_OBJECT (widget), "handle-button-release",
-                       GINT_TO_POINTER (TRUE));
-
-    if (event->button == 3)
-    {
-        slot = caja_window_get_active_slot (CAJA_WINDOW_PANE (pane)->window);
-        view = slot->content_view;
-        if (view != NULL)
-        {
-            location = caja_path_bar_get_path_for_button (
-                           CAJA_PATH_BAR (pane->path_bar), widget);
-            if (location != NULL)
-            {
-                uri = g_file_get_uri (location);
-                caja_view_pop_up_location_context_menu (
-                    view, event, uri);
-                g_object_unref (G_OBJECT (location));
-                g_free (uri);
-                return TRUE;
-            }
-        }
-    }
-
-    return FALSE;
-}
-
-static gboolean
-path_bar_button_released_callback (GtkWidget *widget,
-                                   GdkEventButton *event,
-                                   CajaNavigationWindowPane *pane)
 {
     CajaWindowSlot *slot;
     CajaWindowOpenFlags flags;
-    GFile *location;
     int mask;
-    gboolean handle_button_release;
+    CajaView *view;
+    char *uri;
 
-    mask = event->state & gtk_accelerator_get_default_mod_mask ();
-    flags = 0;
-
-    handle_button_release = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (widget),
-                            "handle-button-release"));
-
-    if (event->type == GDK_BUTTON_RELEASE && handle_button_release)
-    {
-        location = caja_path_bar_get_path_for_button (CAJA_PATH_BAR (pane->path_bar), widget);
+    if (event->type == GDK_BUTTON_RELEASE) {
+        mask = event->state & gtk_accelerator_get_default_mod_mask ();
+        flags = 0;
 
         if (event->button == 2 && mask == 0)
         {
@@ -335,25 +292,24 @@ path_bar_button_released_callback (GtkWidget *widget,
             caja_window_slot_info_open_location (slot, location,
                                                  CAJA_WINDOW_OPEN_ACCORDING_TO_MODE,
                                                  flags, NULL);
-            g_object_unref (location);
-            return TRUE;
         }
 
-        g_object_unref (location);
+         return FALSE;
     }
 
+    if (event->button == 3) {
+        slot = caja_window_get_active_slot (pane->window);
+        view = slot->content_view;
+        if (view != NULL) {
+            uri = g_file_get_uri (location);
+            caja_view_pop_up_location_context_menu (view, event, uri);
+            g_free (uri);
+        }
+        return TRUE;
+    }
     return FALSE;
 }
 
-static void
-path_bar_button_drag_begin_callback (GtkWidget *widget,
-                                     GdkEventButton *event,
-                                     gpointer user_data)
-{
-    g_object_set_data (G_OBJECT (widget), "handle-button-release",
-                       GINT_TO_POINTER (FALSE));
-}
-
 static void
 notebook_popup_menu_new_tab_cb (GtkMenuItem *menuitem,
     			gpointer user_data)
@@ -364,46 +320,6 @@ notebook_popup_menu_new_tab_cb (GtkMenuItem *menuitem,
     caja_window_new_tab (pane->window);
 }
 
-static void
-path_bar_path_set_callback (GtkWidget *widget,
-                            GFile *location,
-                            CajaNavigationWindowPane *pane)
-{
-    GList *children, *l;
-    GtkWidget *child;
-
-    children = gtk_container_get_children (GTK_CONTAINER (widget));
-
-    for (l = children; l != NULL; l = l->next)
-    {
-        child = GTK_WIDGET (l->data);
-
-        if (!GTK_IS_TOGGLE_BUTTON (child))
-        {
-            continue;
-        }
-
-        if (!g_signal_handler_find (child,
-                                    G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
-                                    0, 0, NULL,
-                                    path_bar_button_pressed_callback,
-                                    pane))
-        {
-            g_signal_connect (child, "button-press-event",
-                              G_CALLBACK (path_bar_button_pressed_callback),
-                              pane);
-            g_signal_connect (child, "button-release-event",
-                              G_CALLBACK (path_bar_button_released_callback),
-                              pane);
-            g_signal_connect (child, "drag-begin",
-                              G_CALLBACK (path_bar_button_drag_begin_callback),
-                              pane);
-        }
-    }
-
-    g_list_free (children);
-}
-
 static void
 notebook_popup_menu_move_left_cb (GtkMenuItem *menuitem,
                                   gpointer user_data)
@@ -442,8 +358,6 @@ notebook_popup_menu_show (CajaNavigationWindowPane *pane,
 {
     GtkWidget *popup;
     GtkWidget *item;
-    GtkWidget *image;
-    int button, event_time;
     gboolean can_move_left, can_move_right;
     CajaNotebook *notebook;
 
@@ -454,7 +368,9 @@ notebook_popup_menu_show (CajaNavigationWindowPane *pane,
 
     popup = gtk_menu_new();
 
-    item = gtk_menu_item_new_with_mnemonic (_("_New Tab"));
+    gtk_menu_set_reserve_toggle_size (GTK_MENU (popup), FALSE);
+
+    item = eel_image_menu_item_new_from_icon (NULL, _("_New Tab"));
     g_signal_connect (item, "activate",
     		  G_CALLBACK (notebook_popup_menu_new_tab_cb),
     		  pane);
@@ -464,7 +380,7 @@ notebook_popup_menu_show (CajaNavigationWindowPane *pane,
     gtk_menu_shell_append (GTK_MENU_SHELL (popup),
     		       gtk_separator_menu_item_new ());
 
-    item = gtk_menu_item_new_with_mnemonic (_("Move Tab _Left"));
+    item = eel_image_menu_item_new_from_icon (NULL, _("Move Tab _Left"));
     g_signal_connect (item, "activate",
                       G_CALLBACK (notebook_popup_menu_move_left_cb),
                       pane);
@@ -472,7 +388,7 @@ notebook_popup_menu_show (CajaNavigationWindowPane *pane,
                            item);
     gtk_widget_set_sensitive (item, can_move_left);
 
-    item = gtk_menu_item_new_with_mnemonic (_("Move Tab _Right"));
+    item = eel_image_menu_item_new_from_icon (NULL, _("Move Tab _Right"));
     g_signal_connect (item, "activate",
                       G_CALLBACK (notebook_popup_menu_move_right_cb),
                       pane);
@@ -483,9 +399,8 @@ notebook_popup_menu_show (CajaNavigationWindowPane *pane,
     gtk_menu_shell_append (GTK_MENU_SHELL (popup),
                            gtk_separator_menu_item_new ());
 
-    item = gtk_image_menu_item_new_with_mnemonic (_("_Close Tab"));
-    image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+    item = eel_image_menu_item_new_from_icon ("window-close", _("_Close Tab"));
+
     g_signal_connect (item, "activate",
                       G_CALLBACK (notebook_popup_menu_close_cb), pane);
     gtk_menu_shell_append (GTK_MENU_SHELL (popup),
@@ -493,24 +408,13 @@ notebook_popup_menu_show (CajaNavigationWindowPane *pane,
 
     gtk_widget_show_all (popup);
 
-    if (event)
-    {
-        button = event->button;
-        event_time = event->time;
-    }
-    else
-    {
-        button = 0;
-        event_time = gtk_get_current_event_time ();
-    }
-
     /* TODO is this correct? */
     gtk_menu_attach_to_widget (GTK_MENU (popup),
                                pane->notebook,
                                NULL);
 
-    gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
-                    button, event_time);
+    gtk_menu_popup_at_pointer (GTK_MENU (popup),
+                               (const GdkEvent*) event);
 }
 
 /* emitted when the user clicks the "close" button of tabs */
@@ -767,8 +671,9 @@ caja_navigation_window_pane_setup (CajaNavigationWindowPane *pane)
 
     g_signal_connect_object (pane->path_bar, "path_clicked",
                              G_CALLBACK (path_bar_location_changed_callback), pane, 0);
-    g_signal_connect_object (pane->path_bar, "path_set",
-                             G_CALLBACK (path_bar_path_set_callback), pane, 0);
+
+    g_signal_connect_object (pane->path_bar, "path-event",
+                             G_CALLBACK (path_bar_path_event_callback), pane, 0);
 
     gtk_box_pack_start (GTK_BOX (hbox),
                         pane->path_bar,
