@@ -292,7 +292,7 @@ caja_property_browser_init (CajaPropertyBrowser *property_browser)
 
     /* set the title and standard close accelerator */
     gtk_window_set_title (GTK_WINDOW (widget), _("Backgrounds and Emblems"));
-    gtk_window_set_wmclass (GTK_WINDOW (widget), "property_browser", "Caja");
+
     gtk_window_set_type_hint (GTK_WINDOW (widget), GDK_WINDOW_TYPE_HINT_DIALOG);
 
     GtkStyleContext *context;
@@ -387,14 +387,17 @@ caja_property_browser_init (CajaPropertyBrowser *property_browser)
     gtk_container_add (GTK_CONTAINER (temp_box), property_browser->details->bottom_box);
 
     /* create the "help" button */
-    temp_button = gtk_button_new_from_stock (GTK_STOCK_HELP);
+    temp_button = gtk_button_new_with_mnemonic (_("_Help"));
+    gtk_button_set_image (GTK_BUTTON (temp_button), gtk_image_new_from_icon_name ("help-browser", GTK_ICON_SIZE_BUTTON));
 
     gtk_widget_show (temp_button);
     gtk_box_pack_start (GTK_BOX (property_browser->details->bottom_box), temp_button, FALSE, FALSE, 0);
     g_signal_connect_object (temp_button, "clicked", G_CALLBACK (help_button_callback), property_browser, 0);
 
-    /* create the "done" button */
-    temp_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+    /* create the "close" button */
+    temp_button = gtk_button_new_with_mnemonic (_("_Close"));
+    gtk_button_set_image (GTK_BUTTON (temp_button), gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_BUTTON));
+
     gtk_widget_set_can_default (temp_button, TRUE);
 
     gtk_widget_show (temp_button);
@@ -406,7 +409,7 @@ caja_property_browser_init (CajaPropertyBrowser *property_browser)
     /* create the "remove" button */
     property_browser->details->remove_button = gtk_button_new_with_mnemonic (_("_Remove..."));
 
-    property_browser->details->remove_button_image = gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_BUTTON);
+    property_browser->details->remove_button_image = gtk_image_new_from_icon_name ("list-remove", GTK_ICON_SIZE_BUTTON);
     gtk_button_set_image (GTK_BUTTON (property_browser->details->remove_button),
                           property_browser->details->remove_button_image);
     gtk_widget_show_all (property_browser->details->remove_button);
@@ -420,7 +423,7 @@ caja_property_browser_init (CajaPropertyBrowser *property_browser)
     /* now create the "add new" button */
     property_browser->details->add_button = gtk_button_new_with_mnemonic (_("Add new..."));
 
-    property_browser->details->add_button_image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
+    property_browser->details->add_button_image = gtk_image_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON);
     gtk_button_set_image (GTK_BUTTON (property_browser->details->add_button),
                           property_browser->details->add_button_image);
     gtk_widget_show_all (property_browser->details->add_button);
@@ -1059,11 +1062,11 @@ icon_button_clicked_cb (GtkButton *b,
     GtkWidget *preview;
     int res;
 
-    dialog = gtk_file_chooser_dialog_new (_("Select an Image File for the New Emblem"),
+    dialog = eel_file_chooser_dialog_new (_("Select an Image File for the New Emblem"),
                                           GTK_WINDOW (browser),
                                           GTK_FILE_CHOOSER_ACTION_OPEN,
-                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                          GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                          "process-stop", GTK_RESPONSE_CANCEL,
+                                          "document-open", GTK_RESPONSE_ACCEPT,
                                           NULL);
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
                                          DATADIR "/pixmaps");
@@ -1100,11 +1103,19 @@ caja_emblem_dialog_new (CajaPropertyBrowser *property_browser)
     GtkWidget *label;
     GtkWidget *grid = gtk_grid_new ();
 
-    dialog = gtk_dialog_new_with_buttons (_("Create a New Emblem"),
-                                          GTK_WINDOW (property_browser), 0,
-                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                          GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                          NULL);
+    dialog = gtk_dialog_new ();
+    gtk_window_set_title (GTK_WINDOW (dialog), _("Create a New Emblem"));
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (property_browser));
+
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_Cancel"),
+                           "process-stop",
+                           GTK_RESPONSE_CANCEL);
+
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_OK"),
+                           "gtk-ok",
+                           GTK_RESPONSE_OK);
 
     /* install the grid in the dialog */
     gtk_container_set_border_width (GTK_CONTAINER (grid), 5);
@@ -1172,11 +1183,19 @@ caja_color_selection_dialog_new (CajaPropertyBrowser *property_browser)
 
     GtkWidget *grid = gtk_grid_new ();
 
-    dialog = gtk_dialog_new_with_buttons (_("Create a New Color:"),
-                                          GTK_WINDOW (property_browser), 0,
-                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                          GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                          NULL);
+    dialog = gtk_dialog_new ();
+    gtk_window_set_title (GTK_WINDOW (dialog), _("Create a New Color:"));
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (property_browser));
+
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_Cancel"),
+                           "process-stop",
+                           GTK_RESPONSE_CANCEL);
+
+    eel_dialog_add_button (GTK_DIALOG (dialog),
+                           _("_OK"),
+                           "gtk-ok",
+                           GTK_RESPONSE_OK);
 
     /* install the grid in the dialog */
     gtk_widget_show (grid);
@@ -1300,11 +1319,11 @@ add_new_pattern (CajaPropertyBrowser *property_browser)
     else
     {
         property_browser->details->patterns_dialog = dialog =
-                    gtk_file_chooser_dialog_new (_("Select an Image File to Add as a Pattern"),
+                    eel_file_chooser_dialog_new (_("Select an Image File to Add as a Pattern"),
                             GTK_WINDOW (property_browser),
                             GTK_FILE_CHOOSER_ACTION_OPEN,
-                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                            "process-stop", GTK_RESPONSE_CANCEL,
+                            "document-open", GTK_RESPONSE_ACCEPT,
                             NULL);
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
                                              DATADIR "/caja/patterns/");
@@ -2286,15 +2305,15 @@ caja_property_browser_update_contents (CajaPropertyBrowser *property_browser)
     else
     {
         char *label_text;
-        char *stock_id;
+        char *icon_name;
         if (property_browser->details->remove_mode)
         {
-            stock_id = GTK_STOCK_CANCEL;
+            icon_name = "process-stop";
             text = _("C_ancel Remove");
         }
         else
         {
-            stock_id = GTK_STOCK_ADD;
+            icon_name = "list-add";
             /* FIXME: Using spaces to add padding is not good design. */
             switch (property_browser->details->category_type)
             {
@@ -2314,8 +2333,8 @@ caja_property_browser_update_contents (CajaPropertyBrowser *property_browser)
         }
 
         /* enable the "add new" button and update it's name and icon */
-        gtk_image_set_from_stock (GTK_IMAGE(property_browser->details->add_button_image), stock_id,
-                                  GTK_ICON_SIZE_BUTTON);
+        gtk_image_set_from_icon_name (GTK_IMAGE(property_browser->details->add_button_image), icon_name,
+                                      GTK_ICON_SIZE_BUTTON);
 
         if (text != NULL)
         {
