@@ -31,6 +31,7 @@
 #include <gio/gio.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-glib-extensions.h>
+#include <eel/eel-stock-dialogs.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
@@ -710,11 +711,16 @@ type_combo_changed (GtkComboBox *combo_box, CajaQueryEditorRow *row)
 
 
         toplevel = gtk_widget_get_toplevel (GTK_WIDGET (combo_box));
-        dialog = gtk_dialog_new_with_buttons (_("Select type"),
-                                              GTK_WINDOW (toplevel),
-                                              0,
-                                              GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                              NULL);
+
+        dialog = gtk_dialog_new ();
+        gtk_window_set_title (GTK_WINDOW (dialog), _("Select type"));
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
+
+        eel_dialog_add_button (GTK_DIALOG (dialog),
+                               _("_OK"),
+                               "gtk-ok",
+                               GTK_RESPONSE_OK);
+
         gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 600);
 
         scrolled = gtk_scrolled_window_new (NULL, NULL);
