@@ -25,6 +25,7 @@
 #include "caja-side-pane.h"
 
 #include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
@@ -177,31 +178,6 @@ panel_item_activate_callback (GtkMenuItem *item,
     select_panel (side_pane, panel);
 }
 
-
-static void
-menu_position_under (GtkMenu *menu,
-                     int *x,
-                     int *y,
-                     gboolean *push_in,
-                     gpointer user_data)
-{
-    GtkWidget *widget;
-    GtkAllocation allocation;
-
-    g_return_if_fail (GTK_IS_BUTTON (user_data));
-    g_return_if_fail (!gtk_widget_get_has_window (GTK_WIDGET (user_data)));
-
-    widget = GTK_WIDGET (user_data);
-
-    gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
-    gtk_widget_get_allocation (widget, &allocation);
-
-    *x += allocation.x;
-    *y += allocation.y + allocation.height;
-
-    *push_in = FALSE;
-}
-
 static gboolean
 select_button_press_callback (GtkWidget *widget,
                               GdkEventButton *event,
@@ -227,9 +203,11 @@ select_button_press_callback (GtkWidget *widget,
         gtk_widget_grab_focus (widget);
 
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-        gtk_menu_popup (GTK_MENU (side_pane->details->menu),
-                        NULL, NULL, menu_position_under, widget,
-                        event->button, event->time);
+        gtk_menu_popup_at_widget (GTK_MENU (side_pane->details->menu),
+                                  widget,
+                                  GDK_GRAVITY_SOUTH_WEST,
+                                  GDK_GRAVITY_NORTH_WEST,
+                                  (const GdkEvent*) event);
 
         return TRUE;
     }
@@ -251,9 +229,11 @@ select_button_key_press_callback (GtkWidget *widget,
         event->keyval == GDK_KEY_KP_Enter)
     {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-        gtk_menu_popup (GTK_MENU (side_pane->details->menu),
-                        NULL, NULL, menu_position_under, widget,
-                        1, event->time);
+        gtk_menu_popup_at_widget (GTK_MENU (side_pane->details->menu),
+                                  widget,
+                                  GDK_GRAVITY_SOUTH_WEST,
+                                  GDK_GRAVITY_NORTH_WEST,
+                                  (const GdkEvent*) event);
         return TRUE;
     }
 
@@ -391,6 +371,9 @@ caja_side_pane_init (GObject *object)
                         TRUE, TRUE, 0);
 
     side_pane->details->menu = gtk_menu_new ();
+
+    gtk_menu_set_reserve_toggle_size (GTK_MENU (side_pane->details->menu), FALSE);
+
     g_signal_connect (side_pane->details->menu,
                       "deactivate",
                       G_CALLBACK (menu_deactivate_callback),
@@ -467,7 +450,8 @@ caja_side_pane_add_panel (CajaSidePane *side_pane,
 
     gtk_widget_show (widget);
 
-    panel->menu_item = gtk_image_menu_item_new_with_label (title);
+    panel->menu_item = eel_image_menu_item_new_from_icon (NULL, title);
+
     gtk_widget_show (panel->menu_item);
     gtk_menu_shell_append (GTK_MENU_SHELL (side_pane->details->menu),
                            panel->menu_item);
@@ -608,9 +592,6 @@ caja_side_pane_set_panel_image (CajaSidePane *side_pane,
         image = NULL;
     }
 
-    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (panel->menu_item),
-                                   image);
-
     if (panel->shortcut)
     {
         gtk_widget_destroy (panel->shortcut);
