@@ -244,6 +244,7 @@ caja_sidebar_title_select_text_color (CajaSidebarTitle *sidebar_title,
     GdkRGBA *light_info_color, *dark_info_color;
     GtkStyleContext *style;
     GdkRGBA color;
+    GdkRGBA *c;
 
     g_assert (CAJA_IS_SIDEBAR_TITLE (sidebar_title));
     g_return_if_fail (gtk_widget_get_realized (GTK_WIDGET (sidebar_title)));
@@ -276,11 +277,19 @@ caja_sidebar_title_select_text_color (CajaSidebarTitle *sidebar_title,
     gtk_style_context_get_color (style, GTK_STATE_FLAG_PRELIGHT, &color);
     setup_gc_with_fg (sidebar_title, LABEL_COLOR_PRELIGHT, &color);
 
-    gtk_style_context_get_background_color (style, GTK_STATE_FLAG_SELECTED, &color);
+    gtk_style_context_get (style, GTK_STATE_FLAG_SELECTED,
+                           GTK_STYLE_PROPERTY_BACKGROUND_COLOR,
+                           &c, NULL);
+    color = *c;
+
     setup_gc_with_fg (sidebar_title, LABEL_INFO_COLOR_HIGHLIGHT,
                       eel_gdk_rgba_is_dark (&color) ? light_info_color : dark_info_color);
 
-    gtk_style_context_get_background_color (style, GTK_STATE_FLAG_ACTIVE, &color);
+    gtk_style_context_get (style, GTK_STATE_FLAG_ACTIVE,
+                           GTK_STYLE_PROPERTY_BACKGROUND_COLOR,
+                           &c, NULL);
+    color = *c;
+
     setup_gc_with_fg (sidebar_title, LABEL_INFO_COLOR_ACTIVE,
                       eel_gdk_rgba_is_dark (&color) ? light_info_color : dark_info_color);
 
@@ -293,7 +302,11 @@ caja_sidebar_title_select_text_color (CajaSidebarTitle *sidebar_title,
         gtk_style_context_get_color (style, GTK_STATE_FLAG_NORMAL, &color);
         setup_gc_with_fg (sidebar_title, LABEL_COLOR, &color);
 
-        gtk_style_context_get_background_color (style, GTK_STATE_FLAG_NORMAL, &color);
+        gtk_style_context_get (style, GTK_STATE_FLAG_NORMAL,
+                               GTK_STYLE_PROPERTY_BACKGROUND_COLOR,
+                               &color, NULL);
+        color = *c;
+
         setup_gc_with_fg (sidebar_title, LABEL_INFO_COLOR,
                           eel_gdk_rgba_is_dark (&color) ?
                           light_info_color : dark_info_color);
@@ -315,6 +328,7 @@ caja_sidebar_title_select_text_color (CajaSidebarTitle *sidebar_title,
         setup_gc_with_fg (sidebar_title, LABEL_INFO_COLOR, dark_info_color);
     }
 
+    gdk_rgba_free (c);
     gdk_rgba_free (dark_info_color);
     gdk_rgba_free (light_info_color);
 }
@@ -407,6 +421,35 @@ update_icon (CajaSidebarTitle *sidebar_title)
     }
 }
 
+static void
+override_title_font (GtkWidget   *widget,
+                     const gchar *font)
+{
+    gchar          *css;
+    GtkCssProvider *provider;
+    gchar          *tempsize;
+
+    provider = gtk_css_provider_new ();
+    tempsize = g_strdup (font);
+
+    g_strreverse (tempsize);
+    g_strcanon (tempsize, "1234567890", '\0');
+    g_strreverse (tempsize);
+
+    gchar tempfont [strlen (font)];
+    strcpy (tempfont, font);
+    tempfont [strlen (font) - strlen (tempsize)] = 0;
+
+    css = g_strdup_printf ("label { font-family: %s; font-size: %spt; }", tempfont, tempsize);
+    gtk_css_provider_load_from_data (provider, css, -1, NULL);
+    g_free (css);
+
+    gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
+                                    GTK_STYLE_PROVIDER (provider),
+                                    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    g_object_unref (provider);
+}
+
 static void
 update_title_font (CajaSidebarTitle *sidebar_title)
 {
@@ -435,6 +478,7 @@ update_title_font (CajaSidebarTitle *sidebar_title)
     }
 
     context = gtk_widget_get_style_context (GTK_WIDGET (sidebar_title));
+    state = gtk_widget_get_state_flags (GTK_WIDGET (sidebar_title));
     gtk_style_context_get (context, state, GTK_STYLE_PROPERTY_FONT, &title_font, NULL);
     max_style_font_size = pango_font_description_get_size (title_font) * 1.8 / PANGO_SCALE;
     if (max_style_font_size < MIN_TITLE_FONT_SIZE + 1)
@@ -464,7 +508,9 @@ update_title_font (CajaSidebarTitle *sidebar_title)
 
     pango_font_description_set_size (title_font, max_fit_font_size * PANGO_SCALE);
     pango_font_description_set_weight (title_font, PANGO_WEIGHT_BOLD);
-    gtk_widget_override_font (sidebar_title->details->title_label, title_font);
+
+    override_title_font (sidebar_title->details->title_label, pango_font_description_to_string (title_font));
+
     pango_font_description_free (title_font);
 }
 
