@@ -310,6 +310,7 @@ caja_spatial_window_show (GtkWidget *widget)
 {
     CajaWindow *window;
     CajaWindowSlot *slot;
+    GFile *location;
 
     window = CAJA_WINDOW (widget);
     slot = caja_window_get_active_slot (window);
@@ -320,6 +321,28 @@ caja_spatial_window_show (GtkWidget *widget)
     {
         caja_query_editor_grab_focus (CAJA_QUERY_EDITOR (slot->query_editor));
     }
+
+    location = caja_window_slot_get_location (slot);
+    g_return_if_fail (location != NULL);
+
+    while (location != NULL) {
+        CajaFile *file;
+
+        file = caja_file_get (location);
+
+        if  (!caja_file_check_if_ready (file, CAJA_FILE_ATTRIBUTE_INFO)) {
+            caja_file_call_when_ready (file,
+                                       CAJA_FILE_ATTRIBUTE_INFO,
+                                       NULL,
+                                       NULL);
+        }
+
+        location = g_file_get_parent (location);
+    }
+
+    if (location) {
+        g_object_unref (location);
+    }
 }
 
 static void
@@ -560,49 +583,6 @@ location_menu_item_activated_callback (GtkWidget *menu_item,
     g_object_unref (current);
 }
 
-static void
-got_file_info_for_location_menu_callback (CajaFile *file,
-        gpointer callback_data)
-{
-    GtkWidget *menu_item = callback_data;
-    GtkWidget *label;
-    GtkWidget *icon;
-    GdkPixbuf *pixbuf;
-    char *name;
-
-    g_return_if_fail (CAJA_IS_FILE (file));
-
-    pixbuf = NULL;
-
-    name = caja_file_get_display_name (file);
-    label = gtk_bin_get_child (GTK_BIN (menu_item));
-    gtk_label_set_label (GTK_LABEL (label), name);
-    g_free (name);
-
-    pixbuf = caja_file_get_icon_pixbuf (file,
-                                        caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
-                                        TRUE,
-                                        gtk_widget_get_scale_factor (GTK_WIDGET (menu_item)),
-                                        CAJA_FILE_ICON_FLAGS_IGNORE_VISITING);
-
-    if (pixbuf != NULL)
-    {
-        icon = gtk_image_new_from_pixbuf (pixbuf);
-        g_object_unref (pixbuf);
-    }
-    else
-    {
-        icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
-    }
-
-    if (icon)
-    {
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), icon);
-    }
-    g_object_unref (file);
-    g_object_unref (menu_item);
-}
-
 static void
 menu_deactivate_callback (GtkWidget *menu,
                           gpointer   data)
@@ -663,11 +643,12 @@ location_button_pressed_callback (GtkWidget      *widget,
 }
 
 static void
-location_button_clicked_callback (GtkWidget             *widget,
+location_button_clicked_callback (GtkWidget         *widget,
                                   CajaSpatialWindow *window)
 {
     CajaWindowSlot *slot;
     GtkWidget *popup, *menu_item, *first_item = NULL;
+    GdkPixbuf *pixbuf;
     GFile *location;
     GFile *child_location;
     GMainLoop *loop;
@@ -675,6 +656,9 @@ location_button_clicked_callback (GtkWidget             *widget,
     slot = caja_window_get_active_slot (CAJA_WINDOW (window));
 
     popup = gtk_menu_new ();
+
+    gtk_menu_set_reserve_toggle_size (GTK_MENU (popup), FALSE);
+
     first_item = NULL;
 
     location = caja_window_slot_get_location (slot);
@@ -688,20 +672,29 @@ location_button_clicked_callback (GtkWidget             *widget,
         file = caja_file_get (location);
 
         name = caja_file_get_display_name (file);
-        menu_item = gtk_image_menu_item_new_with_label (name);
-        gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-        g_free (name);
+
+        pixbuf = NULL;
+
+        pixbuf = caja_file_get_icon_pixbuf (file,
+                                            caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
+                                            TRUE,
+                                            gtk_widget_get_scale_factor (widget),
+                                            CAJA_FILE_ICON_FLAGS_IGNORE_VISITING);
+
+        if (pixbuf != NULL)
+        {
+            menu_item = eel_image_menu_item_new_from_pixbuf (pixbuf, name);
+            g_object_unref (pixbuf);
+        }
+        else
+        {
+            menu_item = eel_image_menu_item_new_from_icon ("document-open", name);
+        }
 
         if (first_item == NULL) {
             first_item = menu_item;
         }
 
-        g_object_ref (menu_item);
-        caja_file_call_when_ready (file,
-                                   CAJA_FILE_ATTRIBUTE_INFO,
-                                   got_file_info_for_location_menu_callback,
-                                   menu_item);
-
         gtk_widget_show (menu_item);
         g_signal_connect (menu_item, "activate",
                           G_CALLBACK (location_menu_item_activated_callback),
@@ -875,8 +868,8 @@ caja_spatial_window_set_location_button  (CajaSpatialWindow *window,
             }
             else
             {
-                gtk_image_set_from_stock (GTK_IMAGE (window->details->location_icon),
-                                          GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
+                gtk_image_set_from_icon_name (GTK_IMAGE (window->details->location_icon),
+                                              "document-open", GTK_ICON_SIZE_MENU);
             }
         }
         g_object_unref (file);
@@ -941,31 +934,31 @@ action_search_callback (GtkAction *action,
 
 static const GtkActionEntry spatial_entries[] =
 {
-    /* name, stock id, label */  { SPATIAL_ACTION_PLACES, NULL, N_("_Places") },
-    /* name, stock id, label */  {
+    /* name, icon name, label */ { SPATIAL_ACTION_PLACES, NULL, N_("_Places") },
+    /* name, icon name, label */ {
         SPATIAL_ACTION_GO_TO_LOCATION, NULL, N_("Open _Location..."),
         "<control>L", N_("Specify a location to open"),
         G_CALLBACK (action_go_to_location_callback)
     },
-    /* name, stock id, label */  {
+    /* name, icon name, label */ {
         SPATIAL_ACTION_CLOSE_PARENT_FOLDERS, NULL, N_("Close P_arent Folders"),
         "<control><shift>W", N_("Close this folder's parents"),
         G_CALLBACK (action_close_parent_folders_callback)
     },
-    /* name, stock id, label */  {
+    /* name, icon name, label */ {
         SPATIAL_ACTION_CLOSE_ALL_FOLDERS, NULL, N_("Clos_e All Folders"),
         "<control>Q", N_("Close all folder windows"),
         G_CALLBACK (action_close_all_folders_callback)
     },
-    /* name, stock id, label */  { "Add Bookmark", GTK_STOCK_ADD, N_("_Add Bookmark"),
+    /* name, icon name, label */ { "Add Bookmark", "list-add", N_("_Add Bookmark"),
         "<control>d", N_("Add a bookmark for the current location to this menu"),
         G_CALLBACK (action_add_bookmark_callback)
     },
-    /* name, stock id, label */  { "Edit Bookmarks", NULL, N_("_Edit Bookmarks..."),
+    /* name, icon name, label */ { "Edit Bookmarks", NULL, N_("_Edit Bookmarks..."),
         "<control>b", N_("Display a window that allows editing the bookmarks in this menu"),
         G_CALLBACK (action_edit_bookmarks_callback)
     },
-    /* name, stock id, label */  { "Search", "gtk-find", N_("_Search for Files..."),
+    /* name, icon name, label */ { "Search", "edit-find", N_("_Search for Files..."),
         "<control>F", N_("Locate documents and folders on this computer by name or content"),
         G_CALLBACK (action_search_callback)
     },
@@ -1009,10 +1002,8 @@ caja_spatial_window_init (CajaSpatialWindow *window)
     pane = caja_window_pane_new (win);
     win->details->panes = g_list_prepend (win->details->panes, pane);
 
-    /* FIXME: changing this to gtk_box_new breaks desktop :-/
-     * see https://github.com/mate-desktop/caja/issues/591
-     */
-    vbox = gtk_vbox_new (FALSE, 0);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    gtk_box_set_homogeneous (GTK_BOX (vbox), TRUE);
     gtk_widget_set_hexpand (vbox, TRUE);
     gtk_widget_set_vexpand (vbox, TRUE);
     gtk_grid_attach (GTK_GRID (CAJA_WINDOW (window)->details->grid),
@@ -1036,7 +1027,7 @@ caja_spatial_window_init (CajaSpatialWindow *window)
                        hbox);
     gtk_widget_show (hbox);
 
-    window->details->location_icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
+    window->details->location_icon = gtk_image_new_from_icon_name ("document-open", GTK_ICON_SIZE_MENU);
     gtk_box_pack_start (GTK_BOX (hbox), window->details->location_icon, FALSE, FALSE, 0);
     gtk_widget_show (window->details->location_icon);
 
@@ -1095,7 +1086,6 @@ caja_spatial_window_init (CajaSpatialWindow *window)
     for (i = 0; i < G_N_ELEMENTS (icon_entries); i++)
     {
         menuitem = gtk_ui_manager_get_widget (ui_manager, icon_entries[i]);
-        gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menuitem), TRUE);
     }
     caja_window_set_active_pane (win, pane);
 }
