@@ -124,107 +124,30 @@ zoom_button_clicked (GtkButton *button, CajaZoomControl *zoom_control)
 }
 
 static void
-zoom_popup_menu_show (GdkEventButton *event, CajaZoomControl *zoom_control)
+zoom_popup_menu_show (GtkWidget *widget, GdkEventButton *event, CajaZoomControl *zoom_control)
 {
-    eel_pop_up_context_menu (create_zoom_menu (zoom_control),
-                             EEL_DEFAULT_POPUP_MENU_DISPLACEMENT,
-                             EEL_DEFAULT_POPUP_MENU_DISPLACEMENT,
-                             event);
+    GtkMenu *menu;
+
+    menu = create_zoom_menu (zoom_control);
+    gtk_menu_popup_at_widget (menu,
+                              widget,
+                              GDK_GRAVITY_SOUTH_WEST,
+                              GDK_GRAVITY_NORTH_WEST,
+                              (const GdkEvent*) event);
 }
 
-static void
-menu_position_under_widget (GtkMenu   *menu,
-                            gint      *x,
-                            gint      *y,
-                            gboolean  *push_in,
-                            gpointer   user_data)
-{
-    GtkWidget *widget;
-    GtkWidget *container;
-    GtkRequisition req;
-    GtkRequisition menu_req;
-    GdkRectangle monitor;
-#if GTK_CHECK_VERSION (3, 22, 0)
-    GdkMonitor *monitor_num;
-    GdkDisplay *display;
-#else
-    int monitor_num;
-    GdkScreen *screen;
-#endif
-    GtkAllocation allocation;
-
-    widget = GTK_WIDGET (user_data);
-    g_assert (GTK_IS_WIDGET (widget));
-
-    container = gtk_widget_get_ancestor (widget, GTK_TYPE_CONTAINER);
-    g_assert (container != NULL);
-
-    gtk_widget_get_preferred_size (GTK_WIDGET (menu), &menu_req, NULL);
-    gtk_widget_get_preferred_size (widget, &req, NULL);
-    gtk_widget_get_allocation (widget, &allocation);
-
-#if GTK_CHECK_VERSION (3, 22, 0)
-    display = gtk_widget_get_display (GTK_WIDGET (menu));
-    monitor_num = gdk_display_get_monitor_at_window (display, gtk_widget_get_window (widget));
-    if (monitor_num == NULL)
-        monitor_num = gdk_display_get_monitor (display, 0);
-    gdk_monitor_get_geometry (monitor_num, &monitor);
-#else
-    screen = gtk_widget_get_screen (GTK_WIDGET (menu));
-    monitor_num = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (widget));
-    if (monitor_num < 0)
-    {
-        monitor_num = 0;
-    }
-    gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
-#endif
-
-    gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
-    if (!gtk_widget_get_has_window (widget))
-    {
-        *x += allocation.x;
-        *y += allocation.y;
-    }
-
-    if (gtk_widget_get_direction (container) == GTK_TEXT_DIR_LTR)
-    {
-        *x += allocation.width - req.width;
-    }
-    else
-    {
-        *x += req.width - menu_req.width;
-    }
-
-    if ((*y + allocation.height + menu_req.height) <= monitor.y + monitor.height)
-    {
-        *y += allocation.height;
-    }
-    else if ((*y - menu_req.height) >= monitor.y)
-    {
-        *y -= menu_req.height;
-    }
-    else if (monitor.y + monitor.height - (*y + allocation.height) > *y)
-    {
-        *y += allocation.height;
-    }
-    else
-    {
-        *y -= menu_req.height;
-    }
-
-    *push_in = FALSE;
-}
-
-
 static void
 zoom_popup_menu (GtkWidget *widget, CajaZoomControl *zoom_control)
 {
     GtkMenu *menu;
 
     menu = create_zoom_menu (zoom_control);
-    gtk_menu_popup (menu, NULL, NULL,
-                    menu_position_under_widget, widget,
-                    0, gtk_get_current_event_time ());
+    gtk_menu_popup_at_widget (menu,
+                              widget,
+                              GDK_GRAVITY_SOUTH_WEST,
+                              GDK_GRAVITY_NORTH_WEST,
+                              NULL);
+
     gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
 }
 
@@ -242,7 +165,7 @@ caja_zoom_control_button_press_event (GtkWidget *widget,
     /* check for the context menu button and show the menu */
     if (event->button == CONTEXTUAL_MENU_BUTTON)
     {
-        zoom_popup_menu_show (event, zoom_control);
+        zoom_popup_menu_show (widget, event, zoom_control);
         return TRUE;
     }
     /* We don't change our state (to reflect the new zoom) here.
@@ -324,11 +247,7 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
 
     image = gtk_image_new_from_icon_name ("zoom-out", GTK_ICON_SIZE_MENU);
     zoom_control->details->zoom_out = gtk_button_new ();
-#if GTK_CHECK_VERSION (3, 20, 0)
     gtk_widget_set_focus_on_click (zoom_control->details->zoom_out, FALSE);
-#else
-    gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_out), FALSE);
-#endif
     gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_out),
                            GTK_RELIEF_NONE);
     gtk_widget_set_tooltip_text (zoom_control->details->zoom_out,
@@ -344,11 +263,7 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
                         zoom_control->details->zoom_out, FALSE, FALSE, 0);
 
     zoom_control->details->zoom_button = gtk_button_new ();
-#if GTK_CHECK_VERSION (3, 20, 0)
     gtk_widget_set_focus_on_click (zoom_control->details->zoom_button, FALSE);
-#else
-    gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_button), FALSE);
-#endif
     gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_button),
                            GTK_RELIEF_NONE);
     gtk_widget_set_tooltip_text (zoom_control->details->zoom_button,
@@ -387,11 +302,7 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
 
     image = gtk_image_new_from_icon_name ("zoom-in", GTK_ICON_SIZE_MENU);
     zoom_control->details->zoom_in = gtk_button_new ();
-#if GTK_CHECK_VERSION (3, 20, 0)
     gtk_widget_set_focus_on_click (zoom_control->details->zoom_in, FALSE);
-#else
-    gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_in), FALSE);
-#endif
     gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_in),
                            GTK_RELIEF_NONE);
     gtk_widget_set_tooltip_text (zoom_control->details->zoom_in,
